@@ -1,7 +1,7 @@
 package CPAN::Module::FromURL;
 
 our $DATE = '2016-02-21'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,6 +44,18 @@ $SPEC{extract_module_from_cpan_url} = {
             result => 'Foo::Bar',
         },
 
+        # metacpan.org/release/DIST
+        {
+            args => {url=>'https://metacpan.org/release/Foo-Bar'},
+            result => 'Foo::Bar',
+        },
+
+        # metacpan.org/release/AUTHOR/RELEASE
+        {
+            args => {url=>'https://metacpan.org/release/PAUSEID/Foo-Bar-1.23'},
+            result => 'Foo::Bar',
+        },
+
         # metacpan.org/pod/release/PAUSEID/RELEASE/lib/PKG.pm
         {
             args => {url=>'https://metacpan.org/pod/release/SMONF/Dependencies-Searcher-0.066_001/lib/Dependencies/Searcher.pm'},
@@ -80,6 +92,13 @@ $SPEC{extract_module_from_cpan_url} = {
             result => 'Foo',
         },
 
+        # search.cpan.org/search?mode=module&query=MOD
+        {
+            args => {url=>'http://search.cpan.org/search?mode=module&query=DBIx%3A%3AClass'},
+            result => 'DBIx::Class',
+        },
+
+        # UNKNOWN
         {
             args => {url=>'https://www.google.com/'},
             result => undef,
@@ -100,6 +119,18 @@ sub extract_module_from_cpan_url {
         return $mod;
     }
 
+    if ($url =~ m!\Ahttps?://metacpan\.org/release/(\w+(?:-\w+)*)/?\z!) {
+        my $mod = $1;
+        $mod =~ s!-!::!g;
+        return $mod;
+    }
+
+    if ($url =~ m!\Ahttps?://metacpan\.org/release/[^/]+/(\w+(?:-\w+)*)-\d[^-]*/?\z!) {
+        my $mod = $1;
+        $mod =~ s!-!::!g;
+        return $mod;
+    }
+
     if ($url =~ m!\Ahttps?://search\.cpan\.org/~[^/]+/[^/]+/lib/((?:[^/]+/)*\w+).pm\z!) {
         my $mod = $1;
         $mod =~ s!/!::!g;
@@ -116,6 +147,16 @@ sub extract_module_from_cpan_url {
         return $1;
     }
 
+    # used by perlmonks.org
+    {
+        if ($url =~ m!\Ahttps?://search\.cpan\.org/search\?mode=module&query=(.+)\z!) {
+            require URI::Escape;
+            my $mod = URI::Escape::uri_unescape($1);
+            last unless $mod =~ /\A\w+(::\w+)*\z/;
+            return $mod;
+        }
+    }
+
     undef;
 }
 
@@ -134,7 +175,7 @@ CPAN::Module::FromURL - Detect and extract module name from some CPAN-related UR
 
 =head1 VERSION
 
-This document describes version 0.02 of CPAN::Module::FromURL (from Perl distribution CPAN-Module-FromURL), released on 2016-02-21.
+This document describes version 0.03 of CPAN::Module::FromURL (from Perl distribution CPAN-Module-FromURL), released on 2016-02-21.
 
 =head1 FUNCTIONS
 
@@ -161,13 +202,21 @@ Examples:
 
 =item * Example #4:
 
+ extract_module_from_cpan_url( url => "https://metacpan.org/release/Foo-Bar"); # -> "Foo::Bar"
+
+=item * Example #5:
+
+ extract_module_from_cpan_url( url => "https://metacpan.org/release/PAUSEID/Foo-Bar-1.23"); # -> "Foo::Bar"
+
+=item * Example #6:
+
  extract_module_from_cpan_url(  url => "https://metacpan.org/pod/release/SMONF/Dependencies-Searcher-0.066_001/lib/Dependencies/Searcher.pm");
 
 Result:
 
  "Dependencies::Searcher"
 
-=item * Example #5:
+=item * Example #7:
 
  extract_module_from_cpan_url(  url => "http://metacpan.org/pod/release/SRI/Mojolicious-6.46/lib/Mojo.pm");
 
@@ -175,7 +224,7 @@ Result:
 
  "Mojo"
 
-=item * Example #6:
+=item * Example #8:
 
  extract_module_from_cpan_url(  url => "http://search.cpan.org/~unera/DR-SunDown-0.02/lib/DR/SunDown.pm");
 
@@ -183,23 +232,31 @@ Result:
 
  "DR::SunDown"
 
-=item * Example #7:
+=item * Example #9:
 
  extract_module_from_cpan_url(  url => "https://search.cpan.org/~sri/Mojolicious-6.47/lib/Mojo.pm"); # -> "Mojo"
 
-=item * Example #8:
+=item * Example #10:
 
  extract_module_from_cpan_url( url => "http://search.cpan.org/dist/Foo-Bar/"); # -> "Foo::Bar"
 
-=item * Example #9:
+=item * Example #11:
 
  extract_module_from_cpan_url( url => "http://search.cpan.org/perldoc?Foo::Bar"); # -> "Foo::Bar"
 
-=item * Example #10:
+=item * Example #12:
 
  extract_module_from_cpan_url( url => "http://search.cpan.org/perldoc?Foo"); # -> "Foo"
 
-=item * Example #11:
+=item * Example #13:
+
+ extract_module_from_cpan_url(  url => "http://search.cpan.org/search?mode=module&query=DBIx%3A%3AClass");
+
+Result:
+
+ "DBIx::Class"
+
+=item * Example #14:
 
  extract_module_from_cpan_url( url => "https://www.google.com/"); # -> undef
 
